# Sphinx Veldus Extension v0.1.0

This is a Sphinx Extension built for Veldus.

## Bump version

In there files:

- `setup.py`
- `README.md`

## Package

`$ rm -rf dist/* && python3 setup.py sdist bdist_wheel`

## Upload

`$ python3 -m twine upload dist/*`